@@ -7,9 +7,8 @@ import sys
 class NamesHandler(osmium.SimpleHandler):
 
     def output_pubs(self, tags):
-        if tags.get('amenity') == 'pub':
-            if 'name' in tags:
-                print(tags['name'])
+        if tags.get('amenity') == 'pub' and 'name' in tags:
+            print(tags['name'])
 
     def node(self, n):
         self.output_pubs(n.tags)
