@@ -25,17 +25,23 @@ PYBIND11_MODULE(_osmium, m) {
         }
     });
 
+    py::class_<osmium::handler::NodeLocationsForWays<LocationTable>>(
+        m, "NodeLocationsForWays")
+        .def(py::init<LocationTable&>())
+        .def("ignore_errors", &osmium::handler::NodeLocationsForWays<LocationTable>::ignore_errors)
+    ;
+
     m.def("apply", [](osmium::io::Reader &rd, BaseHandler &h)
-                   { osmium::apply(rd, h); },
+                   { py::gil_scoped_release release; osmium::apply(rd, h); },
           py::arg("reader"), py::arg("handler"),
           "Apply a chain of handlers.");
     m.def("apply", [](osmium::io::Reader &rd, NodeLocationHandler &h)
-                   { osmium::apply(rd, h); },
+                   { py::gil_scoped_release release; osmium::apply(rd, h); },
           py::arg("reader"), py::arg("handler"),
           "Apply a chain of handlers.");
     m.def("apply", [](osmium::io::Reader &rd, NodeLocationHandler &l,
                       BaseHandler &h)
-                     { osmium::apply(rd, l, h); },
+                     { py::gil_scoped_release release; osmium::apply(rd, l, h); },
           py::arg("reader"), py::arg("node_handler"), py::arg("handler"),
           "Apply a chain of handlers.");
 
